from django.contrib.auth.models import User
from django.contrib.auth import authenticate, login, logout
from django.contrib.auth.decorators import login_required

from django.shortcuts import render_to_response, redirect

from workshop.reg.models import Event
from workshop.reg import forms as reg_forms
from workshop.reg import events as reg_events

from django.http import HttpResponse

def homepage(request):
    """ see if the user is active.
    If not, only show the re send activation email link.
    else show all the options in homepage.
    """

    user = request.user

    events = Event.objects.all()[:10]


def user_login(request):
    """ get the user object from e-mail and then check for password.
    """

    user = request.user
    if user.is_authenticated():
        return redirect('/reg')

    if request.method == "POST":
        form = reg_forms.LoginForm(request.POST)
        if form.is_valid():
            email = form.cleaned_data['email']
            password = form.cleaned_data['password']
            username = User.objects.get(email__iexact=email).username

            user = authenticate(username=username, password=password)
            login(request, user)
            return redirect('/reg')
        else:
            return render_to_response('login.html', {'form':form})
    else:
        form = reg_forms.LoginForm()
        return render_to_response('login.html', {'form':form})

def user_logout(request):
    """ simply logout the user and redirect to homepage.
    """

    logout(request)
    return redirect('/reg')

def user_register(request):
    """ take the credentials like name, college and gender here itself.
    """

    if request.method == "POST":
        form = reg_forms.RegisterForm(request.POST)
        if form.is_valid():
            data = form.cleaned_data
            reg_events.create_user(email=data['email'], 
                                   password=data['password'],
                                   firstname=data['first_name'],
                                   lastname=data['last_name'], 
                                   gender=data['gender'], 
                                   profession=data['profession'], 
                                   affiliated_to=data['affiliated_to'], 
                                   interests=data['interests']
                                  )
            return render_to_response('account_created.html')
        else:
            return render_to_response('register.html', {'form':form})
    else:
        form = reg_forms.RegisterForm()
        return render_to_response('register.html', {'form':form})
